//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[IHasFuro](index.md)

# IHasFuro

interface [IHasFuro](index.md)

#### Inheritors

| |
|---|
| [Hand](../-hand/index.md) |
| [HandPattern](../-hand-pattern/index.md) |

## Properties

| Name | Summary |
|---|---|
| [furo](furo.md) | [common]<br>abstract val [furo](furo.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Furo](../../mahjongutils.models/-furo/index.md)&gt;<br>副露 |
| [menzen](menzen.md) | [common]<br>open val [menzen](menzen.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)<br>是否门清 |
